==> lightning-grid-0.3.60b1.tar.gz: lightning-grid-0.3.60b1/grid/cli/cli/utilities.py <==
from typing import Any, Dict, io

import click
import yaml

from grid.cli.tracking import Segment, TrackingEvents

DISK_SIZE_ERROR_MSG = "Invalid disk size, should be greater than 100Gb"


def validate_config(cfg: Dict[str, Any]) -> None:
    """
    Validates Grid config.

    Parameters
    ----------
    cfg: Dict[str, Any]
        Dictionary representing a Grid config
    """
    disk_size = cfg['compute']['train'].get('disk_size')
    if disk_size is not None and disk_size < 100:
        raise click.ClickException(DISK_SIZE_ERROR_MSG)

    tracker = Segment()
    tracker.send_event(TrackingEvents.CONFIG_PARSED, properties={'config': cfg})


def read_config(value: io.TextIO):
    """
    Parameters
    ----------
    value:
        A TextIO object that has `.read()` defined for it
    """
    grid_config = value
    if grid_config:
        #  Loads the YML file as passed by the
        #  user.
        try:
            grid_config = yaml.safe_load(value.read())
            if not isinstance(grid_config, dict):
                raise Exception("Unexpected file structure")
        except Exception as e:
            raise click.BadParameter(f'Could not load your YAML config file: {e}')

        #  Adds required structure to the base
        #  YML file, if that structure isn't there.
        if 'compute' not in grid_config:
            grid_config['compute'] = {}
        if 'train' not in grid_config['compute']:
            grid_config['compute']['train'] = {}
    return grid_config


def read_config_callback(ctx, param, value):
    """
    Click callback that reads value from the config file and fix
    the structure if it doesn't exist.
    """
    return read_config(value)


def validate_disk_size_callback(ctx, param, value: int) -> int:
    """
    Validates the disk size upon user input.

    Parameters
    ----------
    ctx
        Click context
    param
        Click parameter
    value: int

    Returns
    --------
    value: int
        Unmodified value if valid
    """
    if value < 100:
        raise click.BadParameter(DISK_SIZE_ERROR_MSG)

    return value

==> lightning-grid-0.3.81.tar.gz: lightning-grid-0.3.81/grid/cli/cli/utilities.py <==
from pathlib import Path
from typing import Any, Dict, io

import click
import yaml

from grid.cli.tracking import Segment, TrackingEvents

DISK_SIZE_ERROR_MSG = "Invalid disk size, should be greater than 100Gb"

# package managers
PIP_MANAGER = 'PIP'
CONDA_MANAGER = 'CONDA'


def validate_config(cfg: Dict[str, Any]) -> None:
    """
    Validates Grid config.

    Parameters
    ----------
    cfg: Dict[str, Any]
        Dictionary representing a Grid config
    """
    disk_size = cfg['compute']['train']['disk_size']
    if disk_size is not None and disk_size < 100:
        raise click.ClickException(DISK_SIZE_ERROR_MSG)

    tracker = Segment()
    tracker.send_event(TrackingEvents.CONFIG_PARSED, properties={'config': cfg})


def read_config(value: io.TextIO):
    """
    Parameters
    ----------
    value:
        A TextIO object that has `.read()` defined for it
    """
    grid_config = value
    if grid_config:
        #  Loads the YML file as passed by the
        #  user.
        try:
            grid_config = yaml.safe_load(value.read())
            if not isinstance(grid_config, dict):
                raise Exception("Unexpected file structure")
        except Exception as e:
            raise click.BadParameter(f'Could not load your YAML config file: {e}')

        #  Adds required structure to the base
        #  YML file, if that structure isn't there.
        if 'compute' not in grid_config:
            grid_config['compute'] = {}
        if 'train' not in grid_config['compute']:
            grid_config['compute']['train'] = {}
    return grid_config


def read_config_callback(ctx, param, value):
    """
    Click callback that reads value from the config file and fix
    the structure if it doesn't exist.
    """
    return read_config(value)


def validate_disk_size_callback(ctx, param, value: int) -> int:
    """
    Validates the disk size upon user input.

    Parameters
    ----------
    ctx
        Click context
    param
        Click parameter
    value: int

    Returns
    --------
    value: int
        Unmodified value if valid
    """
    if value < 100:
        raise click.BadParameter(DISK_SIZE_ERROR_MSG)

    return value


def find_package_manager(file):
    """
    Find the package manager for the provided dependency file depends on basic heuristics.
    We currently assume a minimal conda environment file would have `dependencies` as the
    key that lists all the dependencies, as described here
    https://conda.io/projects/conda/en/latest/user-guide/tasks/manage-environments.html#create-env-file-manually
    """
    if not file:
        raise RuntimeError("Invalid call to find the package manager")
    f = Path(file).open()
    try:
        content = yaml.safe_load(f)
    except Exception:
        # Assuming PIP if yaml load fails
        return PIP_MANAGER
    else:
        if isinstance(content, dict):
            # valid conda env file should have `dependencies` keys
            if 'dependencies' in content:
                return CONDA_MANAGER
    return PIP_MANAGER
